#!/usr/bin/env python
# -*- encoding: utf-8 -*-
'''
@Contact :   liuyuqi.gov@msn.cn
@Time    :   2023/11/13 14:29:00
@License :   Copyright © 2017-2022 liuyuqi. All Rights Reserved.
@Desc    :   circleci api方式设置 Create or update a repository secret

文档：
https://circleci.com/docs/api/v2/index.html#tag/Schedule

'''

from urllib import response
import requests
import json,sys
import base64

class circleciPulbicKey:
    ''' circleci public key '''

    def __init__(self, key_id: str, key: str):
        self.key_id = key_id
        self.key = key


class circleciApi:
    ''' circleci api '''

    _api_url = 'https://circleci.com/api/v2'

    def __init__(self, owner: str, token: str, repo: str):
        self.owner = owner
        self.token = token
        self.repo = repo
        self.public_key = None
        self.sess = requests.Session()
        self.sess.headers.update({
            'Accept': 'application/vnd.circleci.v3+json',
            'X-circleci-Api-Version': '2022-11-28',
            'Authorization': f'Bearer {self.token}'
        })

    def get_circleci_secret(self):
        # https://circleci.com/api/v2/project/{project-slug}/envvar
        url = f'{self._api_url}/project/{self.repo}/envvar'
        response = self.sess.get(url=url)

    def set_update_circleci_secret(self, key: str, value: str):
        url = f'{self._api_url}/project/{self.repo}/envvar'
        data = {
            'name': key,
            'value': value
        }
        response = self.sess.post(url=url, json=data)
        if response.status_code == 200:
            return response.json()
        else:
            print("Failed to update circleci secret.")
            print(f"Response status code: {response.status_code}")
        print(f"Response body: {response.text}")
